AppEntryPagesEntity class

Constructors

AppEntryPagesEntity({String? entryPageId, int? minPrivilege})

Properties

entryPageId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
minPrivilege → int?
final
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? documentID, String? entryPageId, int? minPrivilege}) → AppEntryPagesEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → AppEntryPagesEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → AppEntryPagesEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → AppEntryPagesEntity?