AppPolicyCache class

Implemented types

Constructors

AppPolicyCache(AppPolicyRepository reference)

Properties

fullCache → Map<String?, AppPolicyModel?>
final
hashCode → int
The hash code for this object.
no setterinherited
reference → AppPolicyRepository
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(AppPolicyModel value) → Future<AppPolicyModel>
Add a AppPolicyModel to the repository, cached
override
addEntity(String documentID, AppPolicyEntity value) → Future<AppPolicyEntity>
Add a AppPolicyEntity to the repository, cached
override
changeValue(String documentId, String fieldName, num changeByThisValue) → Future<AppPolicyModel>
override
delete(AppPolicyModel value) → Future<void>
Delete a AppPolicyModel from the repository, cached
override
deleteAll() → Future<void>
override
flush() → void
override
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → AppPolicyEntity?
override
get(String? id, {dynamic onError(Exception)?}) → Future<AppPolicyModel?>
Retrieve a AppPolicyModel with it's id, cached
override
getEntity(String? id, {dynamic onError(Exception)?}) → Future<AppPolicyEntity?>
override
getSubCollection(String documentId, String name) → dynamic
override
listen(AppPolicyModelTrigger trigger, {String? orderBy, bool? descending, Object? startAfter, int? limit, int? privilegeLevel, EliudQuery? eliudQuery}) → StreamSubscription<List<AppPolicyModel?>>
override
listenTo(String documentId, AppPolicyChanged changed, {AppPolicyErrorHandler? errorHandler}) → StreamSubscription<AppPolicyModel?>
override
listenWithDetails(AppPolicyModelTrigger trigger, {String? orderBy, bool? descending, Object? startAfter, int? limit, int? privilegeLevel, EliudQuery? eliudQuery}) → StreamSubscription<List<AppPolicyModel?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timeStampToString(dynamic timeStamp) → String?
override
toString() → String
A string representation of this object.
inherited
update(AppPolicyModel value) → Future<AppPolicyModel>
Update a AppPolicyModel
override
updateEntity(String documentID, AppPolicyEntity value) → Future<AppPolicyEntity>
Update a AppPolicyEntity in the repository, cached
override
values({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Stream<List<AppPolicyModel?>>
Retrieve list of List<AppPolicyModel?>
override
valuesList({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Future<List<AppPolicyModel?>>
override
valuesListWithDetails({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Future<List<AppPolicyModel?>>
override
valuesWithDetails({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Stream<List<AppPolicyModel?>>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited