BackendRequestEntity class

Constructors

BackendRequestEntity({String? description, required String? appId, String? authorId, String? name, String? sendTo, List<Map<String, String>>? collections, bool? processed, int? requestType})

Properties

appId → String?
final
authorId → String?
final
collections → List<Map<String, String>>?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
processed → bool?
final
props → List<Object?>
no setter
requestType → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTo → String?
final

Methods

copyWith({String? documentID, String? description, String? appId, String? authorId, String? name, String? sendTo, List<Map<String, String>>? collections, bool? processed, int? requestType}) → BackendRequestEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → BackendRequestEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → BackendRequestEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → BackendRequestEntity?