BackendRequestModel class

Constructors

BackendRequestModel({required String documentID, String? description, required String appId, String? authorId, String? name, String? sendTo, List<Map<String, String>>? collections, bool? processed, RequestType? requestType})

Properties

appId ↔ String
getter/setter pairoverride
authorId ↔ String?
getter/setter pair
collections ↔ List<Map<String, String>>?
getter/setter pair
description ↔ String?
getter/setter pair
documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String?
getter/setter pair
processed ↔ bool?
getter/setter pair
requestType ↔ RequestType?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTo ↔ String?
getter/setter pair

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? description, String? appId, String? authorId, String? name, String? sendTo, List<Map<String, String>>? collections, bool? processed, RequestType? requestType}) → BackendRequestModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → BackendRequestEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, BackendRequestEntity? entity) → Future<BackendRequestModel?>
fromEntityPlus(String documentID, BackendRequestEntity? entity, {String? appId}) → Future<BackendRequestModel?>

Constants

id → const String
packageName → const String