BlockingModel class

Constructors

BlockingModel({required String documentID, required String memberBlocking, String? memberBeingBlocked})

Properties

documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
memberBeingBlocked ↔ String?
getter/setter pair
memberBlocking ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? memberBlocking, String? memberBeingBlocked}) → BlockingModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → BlockingEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, BlockingEntity? entity) → Future<BlockingModel?>
fromEntityPlus(String documentID, BlockingEntity? entity, {String? appId}) → Future<BlockingModel?>

Constants

id → const String
packageName → const String