MemberMediumContainerEntity class

Constructors

MemberMediumContainerEntity({String? htmlReference, String? memberMediumId})

Properties

hashCode → int
The hash code for this object.
no setterinherited
htmlReference → String?
final
memberMediumId → String?
final
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? documentID, String? htmlReference, String? memberMediumId}) → MemberMediumContainerEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → MemberMediumContainerEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → MemberMediumContainerEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → MemberMediumContainerEntity?